#ifndef TERMINOLOGY_UTF8_H_
#define TERMINOLOGY_UTF8_H_ 1
#include <Eina.h>
int codepoint_to_utf8(Eina_Unicode g, char *txt);

#endif
